@@ -169,6 +169,10 @@ class Manager(object):
         manager = None
 
     def initialize(self):
+        """
+        Load plugins, database, and config. Also initializes (but does not start) the task queue and ipc server.
+        This should only be called after obtaining a lock.
+        """
         if self.initialized:
             raise RuntimeError('Cannot call initialize on an already initialized manager.')
 
@@ -258,13 +262,11 @@ class Manager(object):
 
     def start(self):
         """
-        Starting point when executing from commandline, dispatch execution
-        to correct destination.
+        Starting point when executing from commandline, dispatch execution to correct destination.
 
-        * :meth:`.execute_command`
-        * :meth:`.daemon_command`
-        * :meth:`.webui_command`
-        * CLI plugin callback function
+        If there is a FlexGet process with an ipc server already running, the command will be sent there for execution
+        and results will be streamed back.
+        If not, this will attempt to obtain a lock, initialize the manager, and run the command here.
         """
         # If another process is started, send the execution to the running process
         ipc_info = self.check_ipc_info()
@@ -291,7 +293,14 @@ class Manager(object):
 
     def handle_cli(self, options=None):
         """
-        Runs a cli command.
+        Dispatch a cli command to the appropriate function.
+
+        * :meth:`.execute_command`
+        * :meth:`.daemon_command`
+        * :meth:`.webui_command`
+        * CLI plugin callback function
+
+        The manager should have a lock and be initialized before calling this method.
 
         :param options: argparse options for command. Defaults to options that manager was instantiated with.
         """
@@ -313,15 +322,19 @@ class Manager(object):
 
     def execute_command(self, options):
         """
-        Send execute command to daemon through IPC or perform execution
-        on current process.
+        Handles the 'execute' CLI command.
+
+        If there is already a task queue running in this process, adds the execution to the queue.
+        If FlexGet is being invoked with this command, starts up a task queue and runs the execution.
 
         Fires events:
 
+        * manager.execute.started
         * manager.execute.completed
 
         :param options: argparse options
         """
+        fire_event('manager.execute.started', self, options)
         if self.task_queue.is_alive():
             if len(self.task_queue):
                 log.verbose('There is a task already running, execution queued.')
@@ -331,16 +344,17 @@ class Manager(object):
                 for event in finished_events:
                     event.wait()
         else:
-            fire_event('manager.execute.started', self)
             self.task_queue.start()
             self.ipc_server.start()
             self.execute(options)
             self.shutdown(finish_queue=True)
             self.task_queue.wait()
-            fire_event('manager.execute.completed', self)
+        fire_event('manager.execute.completed', self, options)
 
     def daemon_command(self, options):
         """
+        Handles the 'daemon' CLI command.
+
         Fires events:
 
         * manager.daemon.started
@@ -385,6 +399,8 @@ class Manager(object):
 
     def webui_command(self, options):
         """
+        Handles the 'webui' CLI command.
+
         :param options: argparse options
         """
         if self.is_daemon:
@@ -666,13 +682,6 @@ class Manager(object):
         Session.configure(bind=self.engine)
         # create all tables, doesn't do anything to existing tables
         try:
-            def before_table_create(event, target, bind, tables=None, **kw):
-                if tables:
-                    # We need to acquire a lock if we are creating new tables
-                    # TODO: Detect if any database upgrading is needed and acquire the lock only in one place
-                    self.acquire_lock(event=False).__enter__()
-
-            Base.metadata.append_ddl_listener('before-create', before_table_create)
             Base.metadata.create_all(bind=self.engine)
         except OperationalError as e:
             if os.path.exists(self.db_filename):
