@@ -30,6 +30,8 @@ class PluginSubliminal(object):
           alternatives:
             - eng
           exact_match: no
+          providers: addic7ed, opensubtitles
+          single: no
     """
     
     schema = {
@@ -38,6 +40,8 @@ class PluginSubliminal(object):
             'languages': {'type': 'array', 'items': {'type': 'string'}, 'minItems': 1},
             'alternatives': {'type': 'array', 'items': {'type': 'string'}},
             'exact_match': {'type': 'boolean', 'default': True},
+            'providers': {'type': 'array', 'items': {'type': 'string'}},
+            'single': {'type': 'boolean', 'default': True},
         },
         'additionalProperties': False
     }
@@ -60,9 +64,11 @@ class PluginSubliminal(object):
         """
         Configuration::
             subliminal:
-                languages: List of languages (3-letter ISO-639-3 code) in order of preference. At least one is required.
+                languages: List of languages (as IETF codes) in order of preference. At least one is required.
                 alternatives: List of second-choice languages; subs will be downloaded but entries rejected.
                 exact_match: Use file hash only to search for subs, otherwise Subliminal will try to guess by filename.
+                providers: List of providers from where to download subtitles.
+                single: Download subtitles in single mode (no language code added to subtitle filename).
         """
         if not task.accepted:
             log.debug('nothing accepted, aborting')
@@ -78,10 +84,18 @@ class PluginSubliminal(object):
             pass
         logging.getLogger("subliminal").setLevel(logging.CRITICAL)
         logging.getLogger("enzyme").setLevel(logging.WARNING)
-        langs = set([Language(s) for s in config['languages']])
-        alts = set([Language(s) for s in config.get('alternatives', [])])
+        langs = set([Language.fromietf(s) for s in config['languages']])
+        alts = set([Language.fromietf(s) for s in config.get('alternatives', [])])
         # keep all downloaded subtitles and save to disk when done (no need to write every time)
         downloaded_subtitles = collections.defaultdict(list)
+        providers_list = config.get('providers', None)
+        # test if only one language was provided, if so we will download in single mode
+        # (aka no language code added to subtitle filename)
+        # unless we are forced not to by configuration
+        # if we pass 'yes' for single in configuration but choose more than one language
+        # we ignore the configuration and add the language code to the
+        # potentially downloaded files
+        single_mode = config['single'] and len(langs | alts) <= 1
         for entry in task.accepted:
             if not 'location' in entry:
                 log.warning('Cannot act on entries that do not represent a local file.')
@@ -90,19 +104,22 @@ class PluginSubliminal(object):
             elif not '$RECYCLE.BIN' in entry['location']:  # ignore deleted files in Windows shares
                 try:
                     video = subliminal.scan_video(entry['location'])
+                    log.info('Series name computed for %s was %s' % (entry['location'], video.series))
                     msc = video.scores['hash'] if config['exact_match'] else 0
                     if langs & video.subtitle_languages:
                         continue  # subs for preferred lang(s) already exists
                     else:
-                        subtitle = subliminal.download_best_subtitles([video], langs, min_score=msc)
+                        subtitle = subliminal.download_best_subtitles([video], langs, providers=providers_list, min_score=msc)
                         if subtitle:
                             downloaded_subtitles.update(subtitle)
                             log.info('Subtitles found for %s' % entry['location'])
                         else:
                             # TODO check performance hit -- this explicit check may be better on slower devices
                             # but subliminal already handles it for us, but it loops over all providers before stopping
-                            if alts and (alts - video.subtitle_languages):
-                                subtitle = subliminal.download_best_subtitles([video], alts, min_score=msc)
+                            remaining_alts = alts - video.subtitle_languages
+                            if remaining_alts:
+                                # only try to download for alternatives that aren't alread downloaded
+                                subtitle = subliminal.download_best_subtitles([video], remaining_alts, providers=providers_list, min_score=msc)
                             # this potentially just checks an already checked assignment bleh
                             if subtitle:
                                 downloaded_subtitles.update(subtitle)
@@ -121,7 +138,7 @@ class PluginSubliminal(object):
                     entry.fail(msg)
         if downloaded_subtitles:
             # save subtitles to disk
-            subliminal.save_subtitles(downloaded_subtitles)
+            subliminal.save_subtitles(downloaded_subtitles, single=single_mode)
 
 
 @event('plugin.register')
